@@ -8,13 +8,13 @@ describe Facts::Amzn::Os::Distro::Description do
 
     before do
       allow(Facter::Resolvers::SpecificReleaseFile).to receive(:resolve)
-        .with(:release, release_file: '/etc/system-release').and_return(value)
+        .with(:release, { release_file: '/etc/system-release' }).and_return(value)
     end
 
     it 'calls Facter::Resolvers::SpecificReleaseFile' do
       fact.call_the_resolver
       expect(Facter::Resolvers::SpecificReleaseFile).to have_received(:resolve)
-        .with(:release, release_file: '/etc/system-release')
+        .with(:release, { release_file: '/etc/system-release' })
     end
 
     it 'returns release fact' do
