@@ -10,11 +10,11 @@ describe Facter::Resolvers::Solaris::DmiSparc do
       resolver.instance_variable_set(:@log, log_spy)
       allow(File).to receive(:executable?).with('/usr/sbin/prtdiag').and_return(true)
       allow(Facter::Core::Execution).to receive(:execute)
-        .with('/usr/sbin/prtdiag', logger: log_spy)
+        .with('/usr/sbin/prtdiag', { logger: log_spy })
         .and_return(load_fixture('prtdiag').read)
       allow(File).to receive(:executable?).with('/usr/sbin/sneep').and_return(true)
       allow(Facter::Core::Execution).to receive(:execute)
-        .with('/usr/sbin/sneep', logger: log_spy).and_return('random_string')
+        .with('/usr/sbin/sneep', { logger: log_spy }).and_return('random_string')
     end
 
     after do
